==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/glue_ml_transform/GlueMlTransformParameters.java <==
package com.hashicorp.cdktf.providers.aws.glue_ml_transform;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.113Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.glueMlTransform.GlueMlTransformParameters")
@software.amazon.jsii.Jsii.Proxy(GlueMlTransformParameters.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GlueMlTransformParameters extends software.amazon.jsii.JsiiSerializable {

    /**
     * find_matches_parameters block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#find_matches_parameters GlueMlTransform#find_matches_parameters}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters getFindMatchesParameters();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#transform_type GlueMlTransform#transform_type}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTransformType();

    /**
     * @return a {@link Builder} of {@link GlueMlTransformParameters}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GlueMlTransformParameters}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GlueMlTransformParameters> {
        com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters findMatchesParameters;
        java.lang.String transformType;

        /**
         * Sets the value of {@link GlueMlTransformParameters#getFindMatchesParameters}
         * @param findMatchesParameters find_matches_parameters block. This parameter is required.
         *                              Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#find_matches_parameters GlueMlTransform#find_matches_parameters}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder findMatchesParameters(com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters findMatchesParameters) {
            this.findMatchesParameters = findMatchesParameters;
            return this;
        }

        /**
         * Sets the value of {@link GlueMlTransformParameters#getTransformType}
         * @param transformType Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#transform_type GlueMlTransform#transform_type}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder transformType(java.lang.String transformType) {
            this.transformType = transformType;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GlueMlTransformParameters}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GlueMlTransformParameters build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GlueMlTransformParameters}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GlueMlTransformParameters {
        private final com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters findMatchesParameters;
        private final java.lang.String transformType;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.findMatchesParameters = software.amazon.jsii.Kernel.get(this, "findMatchesParameters", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters.class));
            this.transformType = software.amazon.jsii.Kernel.get(this, "transformType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.findMatchesParameters = java.util.Objects.requireNonNull(builder.findMatchesParameters, "findMatchesParameters is required");
            this.transformType = java.util.Objects.requireNonNull(builder.transformType, "transformType is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters getFindMatchesParameters() {
            return this.findMatchesParameters;
        }

        @Override
        public final java.lang.String getTransformType() {
            return this.transformType;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("findMatchesParameters", om.valueToTree(this.getFindMatchesParameters()));
            data.set("transformType", om.valueToTree(this.getTransformType()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.glueMlTransform.GlueMlTransformParameters"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GlueMlTransformParameters.Jsii$Proxy that = (GlueMlTransformParameters.Jsii$Proxy) o;

            if (!findMatchesParameters.equals(that.findMatchesParameters)) return false;
            return this.transformType.equals(that.transformType);
        }

        @Override
        public final int hashCode() {
            int result = this.findMatchesParameters.hashCode();
            result = 31 * result + (this.transformType.hashCode());
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/glue_ml_transform/GlueMlTransformParameters.java <==
package com.hashicorp.cdktf.providers.aws.glue_ml_transform;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:09.970Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.glueMlTransform.GlueMlTransformParameters")
@software.amazon.jsii.Jsii.Proxy(GlueMlTransformParameters.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GlueMlTransformParameters extends software.amazon.jsii.JsiiSerializable {

    /**
     * find_matches_parameters block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/glue_ml_transform#find_matches_parameters GlueMlTransform#find_matches_parameters}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters getFindMatchesParameters();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/glue_ml_transform#transform_type GlueMlTransform#transform_type}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTransformType();

    /**
     * @return a {@link Builder} of {@link GlueMlTransformParameters}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GlueMlTransformParameters}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GlueMlTransformParameters> {
        com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters findMatchesParameters;
        java.lang.String transformType;

        /**
         * Sets the value of {@link GlueMlTransformParameters#getFindMatchesParameters}
         * @param findMatchesParameters find_matches_parameters block. This parameter is required.
         *                              Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/glue_ml_transform#find_matches_parameters GlueMlTransform#find_matches_parameters}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder findMatchesParameters(com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters findMatchesParameters) {
            this.findMatchesParameters = findMatchesParameters;
            return this;
        }

        /**
         * Sets the value of {@link GlueMlTransformParameters#getTransformType}
         * @param transformType Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/glue_ml_transform#transform_type GlueMlTransform#transform_type}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder transformType(java.lang.String transformType) {
            this.transformType = transformType;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GlueMlTransformParameters}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GlueMlTransformParameters build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GlueMlTransformParameters}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GlueMlTransformParameters {
        private final com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters findMatchesParameters;
        private final java.lang.String transformType;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.findMatchesParameters = software.amazon.jsii.Kernel.get(this, "findMatchesParameters", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters.class));
            this.transformType = software.amazon.jsii.Kernel.get(this, "transformType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.findMatchesParameters = java.util.Objects.requireNonNull(builder.findMatchesParameters, "findMatchesParameters is required");
            this.transformType = java.util.Objects.requireNonNull(builder.transformType, "transformType is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.glue_ml_transform.GlueMlTransformParametersFindMatchesParameters getFindMatchesParameters() {
            return this.findMatchesParameters;
        }

        @Override
        public final java.lang.String getTransformType() {
            return this.transformType;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("findMatchesParameters", om.valueToTree(this.getFindMatchesParameters()));
            data.set("transformType", om.valueToTree(this.getTransformType()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.glueMlTransform.GlueMlTransformParameters"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GlueMlTransformParameters.Jsii$Proxy that = (GlueMlTransformParameters.Jsii$Proxy) o;

            if (!findMatchesParameters.equals(that.findMatchesParameters)) return false;
            return this.transformType.equals(that.transformType);
        }

        @Override
        public final int hashCode() {
            int result = this.findMatchesParameters.hashCode();
            result = 31 * result + (this.transformType.hashCode());
            return result;
        }
    }
}
